/**
 * Random
 * Utilidad para obtener nmeros aleatorios
 * 
 * @author		Dani Llops 
 * @version		1.0
 * 
 * Date Started: 2007/10/28
 * Last Modified: 2008/02/05
 * 
 */

/*
Licensed under the MIT License

Copyright (c) 2007 Dani Llops (http://llops.com/blog)

Permission is hereby granted, free of charge, to any
person obtaining a copy of this software and associated
documentation files (the "Software"), to deal in the
Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the
Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice
shall be included in all copies or substantial portions of
the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

package com.llops.utils
{
	import flash.geom.Point;
	
	public class Random
	{
		// Devuelve un valor entero entre el rango minimo y el maximo (ambos incluidos)
		public static function obtenerEntero(min:Number,max:Number):int
		{
			return Math.floor(Math.random()*(max - min + 1) + min);
		}
		
		// Devuelve un valor flotante entre el rango minimo y el maximo (ambos incluidos)
		public static function obtenerFlotante(min:Number,max:Number):Number
		{
			return Math.random()*(max-min)+min;
		}
		
		// Devuelve un bit (1 o 0)
		// Acepta un porcentaje para influir en las posibilidades (.2 = 20% de obtener 1)
		public static function obtenerBit(porcentaje:Number = .5):int
		{
			return int(Math.random() < porcentaje);
		}
		
		// Devuelve un booleano, simulando cara o cruz
		public static function obtenerBooleano():Boolean
		{
			return Boolean(obtenerEntero(0,1));
		}
		
		// Dado un punto central, el ancho y el alto, devuelve un punto aleatorio dentro del area
		public static function obtenerPuntoRectangulo(centro:Point, ancho:Number, alto:Number):Point
		{
			var x = centro.x + Math.random() * ancho - ancho/2; 
			var y = centro.y + Math.random() * alto - alto/2;
			return new Point(x, y);
		}
		
		// Dado un punto central y el radio del area, devuelve un punto aleatorio dentro del area
		public static function obtenerPuntoCirculo(centro:Point, radio:Number):Point
		{
			var rd:Number = Math.sqrt(Math.random())* radio;
			var angulo:Number = Math.random() * (Math.PI * 2);
			var x = centro.x + Math.cos(angulo) * rd;
			var y = centro.y + Math.sin(angulo) * rd;
			return new Point(x, y);
		}
	}
}